guix_mirror_bot pushed a commit to branch master
in repository guix.

commit 5837d65acd47a68f571d937841ff4d26a9da26d4
Author: Nicolas Graves <[email protected]>
AuthorDate: Thu Jul 24 04:23:33 2025 +0200

    gnu: python-keystoneclient: Update to 5.6.0.
    
    * gnu/packages/openstack.scm (python-keystoneclient): Update to 5.6.0.
    [build-system]: Switch to pyproject-build-system.
    [arguments]<#:phases>: Add phases 'remove-failing-tests, 'check.
    Refresh phase 'relax-requirements.
    [native-inputs]: Add python-bandit, python-tempest, python-setuptools,
    python-wheel.
    [propagated-inputs]: Remove python-babel, python-debtcollector,
    python-iso8601, python-netaddr, python-prettytable, python-six.  Add
    python-packaging, python-pbr.
    
    Change-Id: I11901435aed3a596bc43f89d328f9d8d7d0c7a1a
    Signed-off-by: Sharlatan Hellseher <[email protected]>
---
 gnu/packages/openstack.scm | 56 ++++++++++++++++++++++++++--------------------
 1 file changed, 32 insertions(+), 24 deletions(-)

diff --git a/gnu/packages/openstack.scm b/gnu/packages/openstack.scm
index 80326445ee..2ed7ba0153 100644
--- a/gnu/packages/openstack.scm
+++ b/gnu/packages/openstack.scm
@@ -1061,30 +1061,39 @@ process of writing new clients.")
 (define-public python-keystoneclient
   (package
     (name "python-keystoneclient")
-    (version "5.0.0")
+    (version "5.6.0")
     (source
       (origin
         (method url-fetch)
-        (uri (pypi-uri "python-keystoneclient" version))
+        (uri (pypi-uri "python_keystoneclient" version))
         (sha256
          (base32
-          "0gza5fx3xl3l6vrc6pnhbzhipz1fz9h98kwxqp7mmd90pwrxll0g"))))
-    (build-system python-build-system)
+          "1rqhxvych2a41dxlizz0qy37vs8jcxxy4kk7khw7c03iqypf47bj"))))
+    (build-system pyproject-build-system)
     (arguments
-     '(#:tests? #f   ; FIXME: Many tests are failing.
-       #:phases (modify-phases %standard-phases
-                  (add-after 'unpack 'relax-requirements
-                    (lambda _
-                      (substitute* "test-requirements.txt"
-                        ;; unused, code-quality checks only
-                        (("hacking[<>!=]" line) (string-append "# " line))
-                        (("flake8-.*[<>!=]" line) (string-append "# " line))
-                        (("pycodestyle[<>!=]" line) (string-append "# " line))
-                        (("bandit[<>!=]" line) (string-append "# " line))
-                        (("coverage[<>!=]" line) (string-append "# " line))
-                        (("reno[<>!=]" line) (string-append "# " line))))))))
+     (list
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-after 'unpack 'remove-failing-tests
+            (lambda _
+              ;; XXX: Mostly tests for outdated os-client-config.
+              (delete-file-recursively "keystoneclient/tests/functional/v3")))
+          (replace 'check
+            (lambda* (#:key tests? test-flags #:allow-other-keys)
+              (when tests?
+                (apply invoke "stestr" "run" test-flags))))
+          (add-after 'unpack 'relax-requirements
+            (lambda _
+              (substitute* "test-requirements.txt"
+                ;; XXX: Outdated/discontinued.
+                (("os-client-config[<>!=]" line) (string-append "# " line))
+                ;; unused, code-quality checks only
+                (("(hacking|flake8-.*|pycodestyle|coverage|bandit|reno)[<>!=]"
+                  line)
+                 (string-append "# " line))))))))
     (native-inputs
      (list openssl
+           python-bandit
            python-fixtures
            python-keyring
            python-lxml
@@ -1093,24 +1102,23 @@ process of writing new clients.")
            python-oslotest
            python-pbr
            python-requests-mock
+           python-setuptools
            python-stestr
+           python-tempest
            python-tempest-lib
            python-testresources
            python-testscenarios
-           python-testtools))
+           python-testtools
+           python-wheel))
     (propagated-inputs
-     (list python-babel
-           python-debtcollector
-           python-iso8601
-           python-keystoneauth1
-           python-netaddr
+     (list python-keystoneauth1
            python-oslo-config
            python-oslo-i18n
            python-oslo-serialization
            python-oslo-utils
-           python-prettytable
+           python-packaging
+           python-pbr
            python-requests
-           python-six
            python-stevedore))
     (home-page "https://www.openstack.org/";)
     (synopsis "Client Library for OpenStack Identity")

Reply via email to